@@ -730,7 +730,7 @@ static Bool HandleTopLevelEvent(XEvent *ev)
 	  XChangeProperty(dpy,
 			  req->requestor,
 			  req->property,
-			  XA_INTEGER,
+			  XA_ATOM,
 			  8 * sizeof(int),
 			  PropModeReplace,
                           (unsigned char *) targets,
@@ -980,7 +980,7 @@ static Bool HandleTopLevelEvent(XEvent *ev)
       }
 
       if (emulate_nav &&
-	  ev->xbutton.button >= 5 &&
+	  ev->xbutton.button >= 6 &&
 	  ev->xbutton.button <= 7)
       {
 	int l, ctrlcode;
